#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 contravariant
version:              1.5.5
visibility:           public
id:                   contravariant-1.5.5-VKJo98a2679MZilCyOyb5
key:                  contravariant-1.5.5-VKJo98a2679MZilCyOyb5
license:              BSD-3-Clause
copyright:            Copyright (C) 2007-2015 Edward A. Kmett
maintainer:           Edward A. Kmett <ekmett@gmail.com>
author:               Edward A. Kmett
stability:            provisional
homepage:             http://github.com/ekmett/contravariant/
synopsis:             Contravariant functors
description:          Contravariant functors.
category:             Control, Data
abi:                  007ae6b83cca2f9ead97a40ce79f63d8
exposed:              True
exposed-modules:
    Data.Functor.Contravariant.Compose
    Data.Functor.Contravariant.Divisible
    Data.Functor.Contravariant.Generic

import-dirs:          /usr/lib/ghc-8.10.5/site-local/contravariant-1.5.5
library-dirs:         /usr/lib/ghc-8.10.5/site-local/contravariant-1.5.5
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/i386-linux-ghc-8.10.5/contravariant-1.5.5
hs-libraries:         HScontravariant-1.5.5-VKJo98a2679MZilCyOyb5
depends:
    StateVar-1.2.2-It1hbplVavsB39KpwsXcML base-4.14.2.0
    transformers-0.5.6.2

haddock-interfaces:
    /usr/share/doc/haskell-contravariant/html/contravariant.haddock

haddock-html:         /usr/share/doc/haskell-contravariant/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

